@@ -1,4 +1,3 @@
-from ...abstract_webtools import *
 from ..urlManager import *
 from ..requestManager import *
 from bs4 import BeautifulSoup
@@ -43,9 +42,10 @@ class soupManager:
         - It provides various methods to extract data and discover elements within the source code.
     """
 
-    def __init__(self, url=None, source_code=None, req_mgr=None, parse_type="html.parser"):
+    def __init__(self, url=None,url_mgr=None, source_code=None, req_mgr=None, parse_type="html.parser",soup=None,soup_mgr=None):
         self.url = url
-        self.req_mgr = req_mgr
+        self.url_mgr = get_url_mgr(url=self.url)
+        self.req_mgr = req_mgr or requestManager(url_mgr=self.url_mgr,url=self.url,source_code=source_code)
         self.source_code = (source_code or (req_mgr.source_code if req_mgr else "")) or ""
         self.soup = BeautifulSoup(self.source_code, parse_type)
 
