@@ -173,7 +173,6 @@ class infoRegistry(metaclass=SingletonMeta):
 class VideoDownloader:
     def __init__(self, url, download_directory=None, user_agent=None,
                  video_extention="mp4", download_video=True,
-                 video_path=None,
                  output_filename=None, ydl_opts=None,
                  registry=None, force_refresh=False,
                  flat_layout: bool = False):
@@ -191,7 +190,7 @@ class VideoDownloader:
         self.output_filename = output_filename
         self.force_refresh = force_refresh
         self.flat_layout = flat_layout   # 🔑
-        self.video_path=video_path
+
         self.monitoring = True
         self.pause_event = threading.Event()
 
@@ -253,7 +252,7 @@ class VideoDownloader:
         finally:
             self.stop()
 
-    def _download_single(self, video_url: str,video_path:str=None):
+    def _download_single(self, video_url: str):
         logger.info(f"[VideoDownloader] Processing: {video_url}")
 
         if "youtube.com/watch" in video_url and "v=" not in video_url:
@@ -283,9 +282,9 @@ class VideoDownloader:
                 logger.warning(f"[VideoDownloader] Invalid ext {ext}, forcing mp4")
                 ext = "mp4"
 
-            final_path =info.get("video_path")
+            final_path = os.path.join(dirbase, f"video.{ext}")
             if temp_path != final_path and os.path.isfile(temp_path):
-                shutil.move(temp_path, info.get("video_path"))
+                shutil.move(temp_path, final_path)
 
             minimal_info = {
                 "id": raw_info.get("id"),
